/* EmblDocumentEntry.java
 *
 * created: Sat Sep 11 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/uk/ac/sanger/pathogens/embl/EmblDocumentEntry.java,v 1.1 1999/09/14 10:13:19 kmr Exp $
 */

package uk.ac.sanger.pathogens.embl;

import uk.ac.sanger.pathogens.*;
import java.io.IOException;

/**
 *  A DocumentEntry that can read an EMBL entry from a Document.
 *
 *  @author Kim Rutherford
 *  @version $Id: EmblDocumentEntry.java,v 1.1 1999/09/14 10:13:19 kmr Exp $
 **/

public class EmblDocumentEntry extends PublicDBDocumentEntry {
  /**
   *  Create a new EmblDocumentEntry object associated with the given
   *  Document.
   *  @param document This is the file that we will read from.  This is also
   *    used for saving the entry back to the file it came from and to give
   *    the new object a name.
   *  @exception IOException thrown if there is a problem reading the entry -
   *    most likely ReadFormatException.
   *  @exception InvalidRelationException Thrown if a if a Feature in this
   *    entry has a illegal key/qualifier combination.
   **/
  public EmblDocumentEntry (Document document)
      throws IOException, InvalidRelationException {
    super (document);
  }

  /**
   *  Create a new EmblDocumentEntry that will be a copy of the given
   *  Entry and has no Document associated with it.  The new
   *  EmblDocumentEntry cannot be saved to a file with save () unless save
   *  (Document) has been called first.  The save (Document) method will
   *  assign a Document..
   **/
  public EmblDocumentEntry (final Entry new_entry) {
    super (new_entry);
  }

  /**
   *  Create a new empty EmblDocumentEntry object that has no Document
   *  associated with it.  The new EmblDocumentEntry cannot be saved to a
   *  file with save () unless save (Document) has been called first.  The
   *  save (Document) method will assign a Document.
   **/
  public EmblDocumentEntry () {
    super ();
  }
}
