/* StreamFeature.java (formally ReaderFeature.java)
 *
 * created: Wed Dec 30 1998
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1998,1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/uk/ac/sanger/pathogens/embl/StreamFeature.java,v 1.8 1999/09/15 15:37:53 kmr Exp $
 */

package uk.ac.sanger.pathogens.embl;

import uk.ac.sanger.pathogens.*;
import java.io.*;

/**
 *  This is an implementation of Feature that can read and write itself to a
 *  stream.
 *
 *  @author Kim Rutherford
 *  @version $Id: StreamFeature.java,v 1.8 1999/09/15 15:37:53 kmr Exp $
 **/

interface StreamFeature extends Feature {
  /**
   *  Write this Feature to the given stream.
   *  @param writer The stream to write to.
   *  @param diana_extensions If true then the any diana additions to the embl
   *    file format will be included in the output, otherwise they will be
   *    removed.
   *  @exception IOException thrown if there is an io problem while writing
   *    the Feature.
   **/
  public void writeToStream (final Writer writer,
                             final boolean diana_extensions)
      throws IOException;

  /**
   *  Read the details of a feature from an EMBL stream into the current
   *  object.
   *  @param in_stream the Feature is read from this stream
   *  @exception IOException thrown if there is a problem reading the Feature -
   *    most likely ReadFormatException.
   *  @exception InvalidRelationException Thrown if this Feature cannot contain
   *    the given Qualifier.
   **/
  public void setFromStream (final LinePushBackReader in_stream)
      throws IOException, InvalidRelationException, ReadOnlyException;

  /**
   *  Read some embl feature qualifiers from a stream into a QualifierVector
   *  object.  The stream should contain qualifiers in this form:
   *  <PRE>  /name1=value1/name2="value2"/name3=[value3]  </PRE>
   *  @param in_stream the qualifiers are read from this stream
   *  @exception IOException thrown if there is a problem reading the
   *    qualifiers, such as end of file.
   *  @exception QualifierParseException Thrown if the format of the value
   *    String is not appropriate for a Qualifier with the given name.  Each
   *    qualifier has a specific format for the value part which depends on
   *    the name, for example the value part of /codon_start qualifier must be
   *    a number: 1, 2 or 3.
   *  @return A Vector containing one Qualifier object for each name/value
   *    pair read from the stream.
   **/
//  public static QualifierVector readQualifiers (Reader in_stream)
//      throws QualifierParseException, InvalidQualifierException, IOException;
}
